var powerbi;
(function (powerbi) {
    var visuals;
    (function (visuals) {
        var LongTextViewer1453740445633;
        (function (LongTextViewer1453740445633) {
            function getLongTextViewDefaultChartSettings() {
                return {
                    fillColor: { solid: { color: "#000000" } },
                    fontSize: 19,
                    scrollable: false,
                    verAlignment: TextAlignment.TOP,
                    horAlignment: TextAlignment.LEFT,
                    textTransform: TextTransform.NORMAL,
                    fontFamily: 'Arial'
                };
            }
            function parseSettings(objects) {
                var defaultSettings = getLongTextViewDefaultChartSettings();
                var fontSize = getValue(objects, 'TextScrollDetail', 'fontSize', defaultSettings.fontSize);
                var fontFamily = getValue(objects, 'TextScrollDetail', 'fontFamily', defaultSettings.fontFamily);
                return {
                    fillColor: { solid: { color: getValue(objects, 'TextScrollDetail', 'fillColor', defaultSettings.fillColor).solid.color } },
                    fontSize: fontSize < 1 ? 1 : fontSize,
                    scrollable: getValue(objects, 'TextScrollDetail', 'scrollable', defaultSettings.scrollable),
                    horAlignment: getValue(objects, 'TextScrollDetail', 'horAlignment', defaultSettings.horAlignment),
                    verAlignment: getValue(objects, 'TextScrollDetail', 'verAlignment', defaultSettings.verAlignment),
                    textTransform: getValue(objects, 'TextScrollDetail', 'textTransform', defaultSettings.textTransform),
                    fontFamily: fontFamily == '' ? 'Arial' : fontFamily
                };
            }
            function getValue(objects, objectName, propertyName, defaultValue) {
                if (objects) {
                    var object = objects[objectName];
                    if (object) {
                        var property = object[propertyName];
                        if (property !== undefined) {
                            return property;
                        }
                    }
                }
                return defaultValue;
            }
            LongTextViewer1453740445633.getValue = getValue;
            var TextAlignment;
            (function (TextAlignment) {
                TextAlignment.LEFT = 1;
                TextAlignment.CENTER = 2;
                TextAlignment.RIGHT = 3;
                TextAlignment.TOP = 1;
                TextAlignment.BOTTOM = 3;
                TextAlignment.MIDDLE = 2;
                TextAlignment.horAlignType = powerbi.createEnumType([
                    { value: TextAlignment.LEFT, displayName: "Left" },
                    { value: TextAlignment.CENTER, displayName: "Center" },
                    { value: TextAlignment.RIGHT, displayName: "Right" },
                ]);
                TextAlignment.verAlignType = powerbi.createEnumType([
                    { value: TextAlignment.TOP, displayName: "Top" },
                    { value: TextAlignment.MIDDLE, displayName: "Middle" },
                    { value: TextAlignment.BOTTOM, displayName: "Bottom" },
                ]);
            })(TextAlignment || (TextAlignment = {}));
            var TextTransform;
            (function (TextTransform) {
                TextTransform.NORMAL = 1;
                TextTransform.UPPERCASE = 2;
                TextTransform.LOWERCASE = 3;
                TextTransform.CAPITALIZE = 4;
                TextTransform.type = powerbi.createEnumType([
                    { value: TextTransform.NORMAL, displayName: "Normal" },
                    { value: TextTransform.UPPERCASE, displayName: "Uppercase" },
                    { value: TextTransform.LOWERCASE, displayName: "Lowercase" },
                    { value: TextTransform.CAPITALIZE, displayName: "Capitalize" }
                ]);
            })(TextTransform || (TextTransform = {}));
            var LongTextViewer = (function () {
                function LongTextViewer() {
                }
                LongTextViewer.converter = function (dataView, colors) {
                    var dataElements = [];
                    if (dataView) {
                        var table = dataView.table;
                        if (table) {
                            var rows = table.rows;
                            if (rows && rows.length > 0) {
                                for (var i = 0; i < rows.length; i++) {
                                    dataElements.push({
                                        category: '',
                                        value: rows[i][0]
                                    });
                                }
                            }
                        }
                    }
                    return dataElements;
                };
                /** This is called once when the visual is initialially created */
                LongTextViewer.prototype.init = function (options) {
                    this.colorPalette = options.style.colorPalette.dataColors;
                    this.longTextViewerSettings = getLongTextViewDefaultChartSettings();
                    // element is the element in which your visual will be hosted.
                    this.divCanvas = d3.select(options.element.get(0)).append('div');
                    this.divCanvas.style({ 'overflow': 'auto', 'overflow-x': 'hidden' });
                    this.divContainer = this.divCanvas.append('div');
                };
                /** Update is called for data updates, resizes & formatting changes */
                LongTextViewer.prototype.update = function (options) {
                    var width = options.viewport.width;
                    var height = options.viewport.height;
                    this.divContainer.style({
                        'width': width
                    });
                    var dataViews = options.dataViews;
                    if (!dataViews)
                        return;
                    if (!dataViews[0])
                        return;
                    this.dataView = options.dataViews[0];
                    var viewModel = LongTextViewer.converter(dataViews[0]);
                    var objects = dataViews[0].metadata.objects;
                    this.longTextViewerSettings = parseSettings(objects);
                    var textColor = this.longTextViewerSettings.fillColor;
                    var textFontSize = this.longTextViewerSettings.fontSize;
                    var scrollable = this.longTextViewerSettings.scrollable;
                    var verAlignment = this.longTextViewerSettings.verAlignment;
                    var horAlignment = this.longTextViewerSettings.horAlignment;
                    var textTransform = this.longTextViewerSettings.textTransform;
                    this.divCanvas.style({
                        'width': width + 'px',
                        'height': (height) + 'px',
                        'overflow-x': 'hidden',
                        'overflow': scrollable ? 'auto' : 'hidden'
                    });
                    this.divContainer.selectAll('.textScrollVis').remove();
                    var texts = this.divContainer.selectAll('.textScrollVis').data(viewModel);
                    var p = texts.enter().append('p').style('width', width + 'px').style('display', viewModel.length > 1 ? 'block' : 'table-cell').style('height', viewModel.length > 1 ? '100%' : ((height - 5) + 'px')).style('vertical-align', (verAlignment == TextAlignment.TOP ? 'top' : (verAlignment == TextAlignment.BOTTOM ? 'bottom' : 'middle'))).classed('textScrollVis', true);
                    texts.style("font-size", textFontSize + "pt").style("color", textColor.solid.color).style("line-height", "100%").style('text-align', (horAlignment == TextAlignment.LEFT ? 'left' : (horAlignment == TextAlignment.RIGHT ? 'right' : 'center'))).text(function (d) {
                        return d.value;
                    });
                    switch (textTransform) {
                        case 1:
                            texts.style("text-transform", "");
                            break;
                        case 2:
                            texts.style("text-transform", "uppercase");
                            break;
                        case 3:
                            texts.style("text-transform", "lowercase");
                            break;
                        case 4:
                            texts.style("text-transform", "capitalize");
                            break;
                    }
                    if (this.longTextViewerSettings.fontFamily != '')
                        texts.style("font-family", '"' + this.longTextViewerSettings.fontFamily + '", Arial');
                    texts.exit().remove();
                };
                LongTextViewer.prototype.enumerateObjectInstances = function (options) {
                    var enumeration = new visuals.ObjectEnumerationBuilder();
                    switch (options.objectName) {
                        case 'TextScrollDetail':
                            enumeration.pushInstance({
                                objectName: 'TextScrollDetail',
                                displayName: 'Text',
                                selector: null,
                                properties: {
                                    fillColor: this.longTextViewerSettings.fillColor.solid.color,
                                    fontSize: this.longTextViewerSettings.fontSize,
                                    scrollable: this.longTextViewerSettings.scrollable,
                                    verAlignment: this.longTextViewerSettings.verAlignment,
                                    horAlignment: this.longTextViewerSettings.horAlignment,
                                    textTransform: this.longTextViewerSettings.textTransform,
                                    fontFamily: this.longTextViewerSettings.fontFamily
                                }
                            });
                            break;
                    }
                    return enumeration.complete();
                };
                LongTextViewer.capabilities = {
                    // This is what will appear in the 'Field Wells' in reports
                    dataRoles: [
                        {
                            name: 'Category',
                            kind: powerbi.VisualDataRoleKind.GroupingOrMeasure,
                            displayName: 'Category',
                        }
                    ],
                    // This tells power bi how to map your roles above into the dataview you will receive
                    dataViewMappings: [{
                        conditions: [
                            { 'Category': { max: 1 } },
                        ],
                        categorical: {
                            categories: {
                                for: { in: 'Category' },
                                dataReductionAlgorithm: { top: {} }
                            },
                            rowCount: { preferred: { min: 1 } }
                        }
                    }],
                    // Objects light up the formatting pane
                    objects: {
                        general: {
                            displayName: powerbi.data.createDisplayNameGetter('Visual_General'),
                            properties: {
                                formatString: {
                                    type: { formatting: { formatString: true } },
                                },
                            },
                        },
                        TextScrollDetail: {
                            displayName: 'Text',
                            properties: {
                                fillColor: {
                                    displayName: 'Font color',
                                    description: 'Font color of visual',
                                    type: { fill: { solid: { color: true } } }
                                },
                                fontSize: {
                                    displayName: 'Text Size',
                                    description: 'Font size of visual',
                                    type: { numeric: true }
                                },
                                scrollable: {
                                    displayName: "Scrollable",
                                    type: { bool: true }
                                },
                                verAlignment: {
                                    displayName: "Vertical alignment",
                                    type: {
                                        enumeration: TextAlignment.verAlignType
                                    }
                                },
                                horAlignment: {
                                    displayName: "Horizontal alignment",
                                    type: {
                                        enumeration: TextAlignment.horAlignType
                                    }
                                },
                                textTransform: {
                                    displayName: "Text transform",
                                    type: {
                                        enumeration: TextTransform.type
                                    }
                                },
                                fontFamily: {
                                    displayName: "Font family",
                                    type: { text: true }
                                }
                            }
                        }
                    }
                };
                return LongTextViewer;
            })();
            LongTextViewer1453740445633.LongTextViewer = LongTextViewer;
        })(LongTextViewer1453740445633 = visuals.LongTextViewer1453740445633 || (visuals.LongTextViewer1453740445633 = {}));
    })(visuals = powerbi.visuals || (powerbi.visuals = {}));
})(powerbi || (powerbi = {}));
var powerbi;
(function (powerbi) {
    var visuals;
    (function (visuals) {
        var plugins;
        (function (plugins) {
            plugins.LongTextViewer1453740445633 = {
                name: 'LongTextViewer1453740445633',
                class: 'LongTextViewer1453740445633',
                capabilities: powerbi.visuals.LongTextViewer1453740445633.LongTextViewer.capabilities,
                custom: true,
                create: function (options) { return new powerbi.visuals.LongTextViewer1453740445633.LongTextViewer(options); },
                apiVersion: null
            };
        })(plugins = visuals.plugins || (visuals.plugins = {}));
    })(visuals = powerbi.visuals || (powerbi.visuals = {}));
})(powerbi || (powerbi = {}));
